@@ -11,13 +11,13 @@ pub fn room_enter_message(config: &StreamConfig) -> Message {
             Operation::RoomEnter,
             Protocol::Json,
             serde_json::to_vec(&json!({
-                "uid": config.uid,
-                "roomid": config.room_id,
+                "uid": config.uid(),
+                "roomid": config.room_id(),
                 "protover": 2,
                 "platform": "web",
                 "clientver": "1.8.2",
                 "type": 2,
-                "key": config.token
+                "key": config.token()
             }))
             .unwrap(),
         )
